#
#      File: read.r
#
#      Loads data and sets up smoothing parameters
#
load("Sweden.males.RData")
#
#   This is data on Swedish males from the Human Mortality Database.
#   These data are for ages 0 to 110 and years 1751 to 2003.
#   You can use your own data of course but it must eventually be in
#   the form
#
#         Age:  the vector of ages
#         Year: the vector of years
#         Dth:  the matrix of deaths (rows indexed by age, columns by
#               year, both in ascending order)
#         Exp:  the matrix of central exposures (indexed as Dth)
#
#   For our example we choose the subset of data with ages 10 to 90
#   and years 1900 to 2000.
#
#   Age and year vectors, deaths and exposures matrices
#
Age <- A[11:91]
Year <- Y[150:250]
Exp <- E[11:91,150:250]
Dth <- D[11:91,150:250]
n.a <- length(Age)
n.y <- length(Year)
rm(D,E,A,Y)
#
#    Weight matrix.  This can be used to cope with missing values or
#    remove outliers from the data.  See Currie, Durban and Eilers (2004)
#    for how this works.  There are no missing values in our example so
#
V <- matrix(1, nrow = nrow(Dth), ncol = ncol(Dth))
#
#    Offset matrix
#
Off <- log(Exp)
#
#     Age, year and shock B-spline parameters.
#     Age.dx is the gap between the knots, etc.
#     These parameters can be reset by the user.
#
Age.dx <- 5
bdeg.a <- 3
pord.a <- 2
#
Year.dx <- 5
bdeg.y <- 3
pord.y <- 2
#
Shock.dx <- 15
bdeg.s <- 3
pord.s <- 2



