#
#    File name: setup.r
#
#    Gets everything ready
#
#    Read in data, load functions and spline library
#
source("read.r")
source("Functions.r")
library(splines)
#
#    NB: Explanations of the various functions are given in
#        the function file: Functions.r
#
#    Age: Calculate the B-spline matrix, B.a, the row tensor of B.a,
#         the difference matrix DtD.a.
#
Age.values <- Setup.X(Age, Age.dx)
x.r.a <- Age.values$X.r
ndx.a <- Age.values$Ndx
Setup.Age <- setup.P(1:nrow(Dth), 1, x.r.a, bdeg.a, pord.a, ndx.a)
B.a <- Setup.Age$B
c.a <- ncol(B.a)
Rten.B.a <- Rten(B.a, B.a)
DtD.a <- Setup.Age$DtD
#
#    Year: Calculate the B-spline matrix, B.y, the row tensor of B.y,
#          the difference matrix DtD.y.
#
Year.values <- Setup.X(Year, Year.dx)
x.r.y <- Year.values$X.r
ndx.y <- Year.values$Ndx
Setup.Year <- setup.P(1:ncol(Dth), 1, x.r.y, bdeg.y, pord.y, ndx.y)
B.y <- Setup.Year$B
c.y <- ncol(B.y)
Rten.B.y <- Rten(B.y, B.y)
DtD.y <- Setup.Year$DtD
#
#    Shock: Calculate the B-spline matrix, B.s, and the row tensor of B.s
#
Shock.values <- Setup.X(Age, Shock.dx)
x.r.s <- Shock.values$X.r
ndx.s <- Shock.values$Ndx
Setup.Shock <- setup.P(1:nrow(Dth), 1, x.r.s, bdeg.s, pord.s, ndx.s)
B.s <- Setup.Shock$B
c.s <- ncol(B.s)
Rten.B.s <- Rten(B.s, B.s)
#
#    Calculate the row tensor of B.a and B.s
#
Rten.Ba.Bs <- Rten(B.a, B.s)
#
#    Calculate penalty matrices
#
P.a <- kronecker(diag(ncol(B.y)), DtD.a)
P.y <- kronecker(DtD.y, diag(ncol(B.a)))
#
#    Initialization of regression coefficients
#
#    Initialize the smooth coefficients by fitting an
#    unpenalized normal model with the log hazard as y
#    and B.y \otimes B.a as regression matrix
#
X.old <- kronecker(B.y, B.a)
temp <- c(log((Dth+1)/(Exp+2)))
A.init <- c(solve(t(X.old) %*% X.old, t(X.old) %*% temp))
#
#    Now improve this by fitting the smooth model with smoothing
#    parameters set to 1.
#
A.init <-  Calc(B.a, B.y, Rten.B.a, Rten.B.y, c.a, c.y, V, Off, Dth,
                A.init, P.a, 1, P.y, 1, 10^(-6), TRUE, 20, TRUE)$a
A.init <- c(A.init)
#
#    Initialize shock coefficients to 0.
#
As.init <- rep(0, c.s*n.y)
